@@ -14,8 +14,10 @@
 #include <gstreamermm/event.h>
 #include <gstreamermm/filter.h>
 #include <gstreamermm/format.h>
+#include <gstreamermm/ghostpad.h>
 #include <gstreamermm/index.h>
 #include <gstreamermm/indexfactory.h>
+#include <gstreamermm/interface.h>
 #include <gstreamermm/iterator.h>
 #include <gstreamermm/message.h>
 #include <gstreamermm/object.h>
@@ -28,6 +30,8 @@
 #include <gstreamermm/query.h>
 #include <gstreamermm/structure.h>
 #include <gstreamermm/systemclock.h>
+#include <gstreamermm/taglist.h>
+#include <gstreamermm/tagsetter.h>
 #include <gstreamermm/task.h>
 #include <gstreamermm/urihandler.h>
 #include <gstreamermm/value.h>
