@@ -25,8 +25,10 @@
 #include "event.h"
 #include "filter.h"
 #include "format.h"
+#include "ghostpad.h"
 #include "index.h"
 #include "indexfactory.h"
+#include "interface.h"
 #include "iterator.h"
 #include "message.h"
 #include "pad.h"
@@ -36,8 +38,10 @@
 #include "plugin.h"
 #include "pluginfeature.h"
 #include "query.h"
+#include "registry.h"
 #include "structure.h"
 #include "systemclock.h"
+#include "tagsetter.h"
 #include "task.h"
 #include "urihandler.h"
 #include "value.h"
