@@ -25,8 +25,10 @@
 #include "event.h"
 #include "filter.h"
 #include "format.h"
+#include "ghostpad.h"
 #include "index.h"
 #include "indexfactory.h"
+#include "interface.h"
 #include "iterator.h"
 #include "message.h"
 #include "pad.h"
@@ -36,8 +38,10 @@
 #include "plugin.h"
 #include "pluginfeature.h"
 #include "query.h"
+#include "registry.h"
 #include "structure.h"
 #include "systemclock.h"
+#include "tagsetter.h"
 #include "task.h"
 #include "urihandler.h"
 #include "value.h"
@@ -53,6 +57,7 @@ GType gst_bus_get_type(void);
 GType gst_clock_get_type(void);
 GType gst_element_get_type(void);
 GType gst_element_factory_get_type(void);
+GType gst_ghost_pad_get_type(void);
 GType gst_index_get_type(void);
 GType gst_index_factory_get_type(void);
 GType gst_pad_get_type(void);
@@ -60,6 +65,7 @@ GType gst_pad_template_get_type(void);
 GType gst_pipeline_get_type(void);
 GType gst_plugin_get_type(void);
 GType gst_plugin_feature_get_type(void);
+GType gst_registry_get_type(void);
 GType gst_system_clock_get_type(void);
 GType gst_task_get_type(void);
 GType gst_xml_get_type(void);
@@ -68,6 +74,8 @@ GType gst_xml_get_type(void);
 
 GQuark gst_core_error_quark(void);
 GQuark gst_library_error_quark(void);
+GQuark gst_parse_error_quark(void);
+GQuark gst_plugin_error_quark(void);
 GQuark gst_resource_error_quark(void);
 GQuark gst_stream_error_quark(void);
 } // extern "C"
@@ -80,6 +88,7 @@ namespace Gst {  class Bus_Class { public: static Glib::ObjectBase* wrap_new(GOb
 namespace Gst {  class Clock_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Element_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class ElementFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class GhostPad_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Index_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class IndexFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Pad_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -87,6 +96,7 @@ namespace Gst {  class PadTemplate_Class { public: static Glib::ObjectBase* wrap
 namespace Gst {  class Pipeline_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Plugin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class PluginFeature_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class Registry_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class SystemClock_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Task_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class XML_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -98,6 +108,8 @@ void wrap_init()
   // Register Error domains:
   Glib::Error::register_domain(gst_core_error_quark(), &Gst::CoreError::throw_func);
   Glib::Error::register_domain(gst_library_error_quark(), &Gst::LibraryError::throw_func);
+  Glib::Error::register_domain(gst_parse_error_quark(), &Gst::ParseError::throw_func);
+  Glib::Error::register_domain(gst_plugin_error_quark(), &Gst::PluginError::throw_func);
   Glib::Error::register_domain(gst_resource_error_quark(), &Gst::ResourceError::throw_func);
   Glib::Error::register_domain(gst_stream_error_quark(), &Gst::StreamError::throw_func);
 
@@ -107,6 +119,7 @@ void wrap_init()
   Glib::wrap_register(gst_clock_get_type(), &Gst::Clock_Class::wrap_new);
   Glib::wrap_register(gst_element_get_type(), &Gst::Element_Class::wrap_new);
   Glib::wrap_register(gst_element_factory_get_type(), &Gst::ElementFactory_Class::wrap_new);
+  Glib::wrap_register(gst_ghost_pad_get_type(), &Gst::GhostPad_Class::wrap_new);
   Glib::wrap_register(gst_index_get_type(), &Gst::Index_Class::wrap_new);
   Glib::wrap_register(gst_index_factory_get_type(), &Gst::IndexFactory_Class::wrap_new);
   Glib::wrap_register(gst_pad_get_type(), &Gst::Pad_Class::wrap_new);
@@ -114,6 +127,7 @@ void wrap_init()
   Glib::wrap_register(gst_pipeline_get_type(), &Gst::Pipeline_Class::wrap_new);
   Glib::wrap_register(gst_plugin_get_type(), &Gst::Plugin_Class::wrap_new);
   Glib::wrap_register(gst_plugin_feature_get_type(), &Gst::PluginFeature_Class::wrap_new);
+  Glib::wrap_register(gst_registry_get_type(), &Gst::Registry_Class::wrap_new);
   Glib::wrap_register(gst_system_clock_get_type(), &Gst::SystemClock_Class::wrap_new);
   Glib::wrap_register(gst_task_get_type(), &Gst::Task_Class::wrap_new);
   Glib::wrap_register(gst_xml_get_type(), &Gst::XML_Class::wrap_new);
@@ -124,6 +138,7 @@ void wrap_init()
   Gst::Clock::get_type();
   Gst::Element::get_type();
   Gst::ElementFactory::get_type();
+  Gst::GhostPad::get_type();
   Gst::Index::get_type();
   Gst::IndexFactory::get_type();
   Gst::Pad::get_type();
@@ -131,6 +146,7 @@ void wrap_init()
   Gst::Pipeline::get_type();
   Gst::Plugin::get_type();
   Gst::PluginFeature::get_type();
+  Gst::Registry::get_type();
   Gst::SystemClock::get_type();
   Gst::Task::get_type();
   Gst::XML::get_type();
